#!/bin/bash
# (c) Copyright 2007-2013 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

################################################################################
# Script that starts/stops an application server for SG/LX. 
# (As know as Toolkit Interface Script.)
#
# If the HA server scripts exist in the package directory, the server scripts 
# will be invoked.
#
# This script has one parameter passed to it, which then will be passed to the HA
# server main script:
# - start - to indicate the package is starting up
# - stop  - to indicate the package is shutting down
# - monitor - to indicate to invoke the monitoring script 
# This script exit on one of the following code:
#  0: on success
#  1: on fail
#
################################################################################ 


HA_SERVER=SENDMAIL
HA_SCRIPT=${0%/*}/hasendmail.sh
ACT=$1


# Function to test the return code
function test_return
{
    if (( $? != 0 ))
    then
        echo "ERROR: $(date '+%b %e %T') - Failed to $ACT $HA_SERVER."
        exit 1
    fi
}


# Function to log a warning message
function log_info
{
    if [[ "$ACT" = "start" ]]
    then
        echo -e "WARNING: The application script \"$HA_SCRIPT\" does not exist"
        echo -e "\t or is not executable. To run the application server on this node either"
        echo -e "\t copy the script to this package directory or use the chmod(1)"
        echo -e "\t command to make file $HA_SCRIPT executable. Then restart this package."
    else
        echo -e "WARNING: The application control script \"$HA_SCRIPT\" does not exist or"
        echo -e "\t is not excutable. Either copy the script to this package directory"
        echo -e "\t or use the chmod(1) command to make file $HA_NFS_SCRIPT executable"
        echo -e "\t (You may need to manually clean application resources.)"
    fi
}


# Invoke the application toolkit

if [ -x $HA_SCRIPT ]; then
    . $HA_SCRIPT $ACT
    test_return
else
    log_info
fi

exit 0
